## ----setup, include=F----------------------------------------------------
knitr::opts_chunk$set(eval=TRUE)

## ----start---------------------------------------------------------------
library(ggseg)
library(magrittr)
library(dplyr)
library(ggplot2)
atlas.info$yeo7

## ------------------------------------------------------------------------
someData = data.frame(area=c("default","visual"),
                      p=c(.03,.6), 
                      stringsAsFactors = F)
someData

## ------------------------------------------------------------------------
yeo7 %>% 
  left_join(someData) %>% 
  head(10) #only added to truncate output

## ------------------------------------------------------------------------
yeo7 %>% 
  left_join(someData) %>% 
  arrange(p) %>% 
  head(10) #only added to truncate output

## ------------------------------------------------------------------------
someData$hemi = c("left","left")
someData

yeo7 %>% 
  left_join(someData) %>% 
  arrange(p) %>% 
  head(10)

## ------------------------------------------------------------------------
library(ggplot2)
ggseg(someData, atlas="yeo7", mapping=aes(fill=p))

## ------------------------------------------------------------------------
newAtlas = yeo7 %>% 
  left_join(someData)

ggseg(atlas=newAtlas, mapping=aes(fill=p), position="stacked")

## ----datasupp3-----------------------------------------------------------
someData = data.frame(
  area = rep(c("transverse temporal", "insula",
               "pre central","superior parietal"),2), 
  p = sample(seq(0,.5,.001), 8),
  AgeG = c(rep("Young",4), rep("Old",4)),
  stringsAsFactors = FALSE)
  
ggseg(data=someData, colour="white", mapping=aes(fill=p)) +
  facet_wrap(~AgeG, ncol=1) +
  theme(legend.position = "bottom")


## ----duplicate-----------------------------------------------------------
# Initiate your list. Creating list newAtlas, that contains two data frames, one for each group
newAtlas = list(Young = someData %>% filter(AgeG %in% "Young"),
                Old = someData %>% filter(AgeG %in% "Old")) 
newAtlas 

# Use list apply (lapply) to do the same operation on each element of the list.
# Here we join each data.frame with the atlas of choice ("dkt"), and make sure the
# group colum "AgeG" has it's group name populated in the column entirely
newAtlas = lapply(newAtlas, function(x) x %>% full_join(dkt) %>% mutate(AgeG = unique(x$AgeG)))

newAtlas %>% lapply(function(x)  head(x,5))
  
# Now, the each data.frame in our list has the exact same columns,
# so we can easily append the dataframes by row.
newAtlas = newAtlas %>% bind_rows()
newAtlas %>% head(5)

# We can now supply the newAtlas as an atlas to ggseg
ggseg(atlas=newAtlas, colour="white", mapping=aes(fill=p)) +
  facet_wrap(~AgeG, ncol=1) +
  theme(legend.position = "bottom")

## ----duplicatepipe-------------------------------------------------------
newAtlas = list(Young = someData %>% filter(AgeG %in% "Young"),
                Old = someData %>% filter(AgeG %in% "Old")) %>% 
  lapply(function(x) x %>% full_join(dkt) %>% mutate(AgeG = unique(x$AgeG))) %>% 
  bind_rows()

ggseg(atlas=newAtlas, colour="white", mapping=aes(fill=p)) +
  facet_wrap(~AgeG, ncol=1) +
  scale_fill_gradientn(colours = c("royalblue","firebrick","goldenrod"),na.value="grey")

