## ----setup, include=F----------------------------------------------------
knitr::opts_chunk$set(eval=TRUE)

## ----start---------------------------------------------------------------
library(ggseg)
library(ggplot2)
library(magrittr)
library(dplyr)
ggseg()

## ----void----------------------------------------------------------------
ggseg() + theme_void()

## ----stacked-------------------------------------------------------------
ggseg(position="stacked") +
  theme_void()

## ----fill----------------------------------------------------------------
ggseg(mapping=aes(fill=area)) +
  theme_void()

## ----fill2---------------------------------------------------------------
ggseg(colour="black", size=.7, mapping=aes(fill=area)) +
  theme_void()

## ----plot.area-----------------------------------------------------------
ggseg(plot.area="superior frontal") +
  theme_void()

## ----plot.area2----------------------------------------------------------
ggseg(plot.area=c("transverse temporal", "insula","pre central","superior parietal")) +
  theme_void()

## ----hemisphere----------------------------------------------------------
ggseg(hemisphere="right") +
  theme_void()

## ----datasupp------------------------------------------------------------
someData = data.frame(
  area = c("transverse temporal", "insula",
           "pre central","superior parietal"), 
  p = sample(seq(0,.5,.001), 4),
  stringsAsFactors = FALSE)

ggseg(data=someData, mapping=aes(fill=p))


## ----datasupp2-----------------------------------------------------------
ggseg(data=someData, colour="black",mapping=aes(fill=p)) +
  theme_void() +
  scale_fill_gradient(low="firebrick",high="goldenrod") +
  labs(title="Aparc plots rule")


## ----datasuppX-----------------------------------------------------------
someData$hemi = "right"

ggseg(data=someData, colour="white",mapping=aes(fill=p)) +
  theme_void() +
  scale_fill_gradient(low="firebrick",high="goldenrod") +
  labs(title="Aparc plots rule")


## ----datasupp3-----------------------------------------------------------
someData = data.frame(
  area = rep(c("transverse temporal", "insula",
               "pre central","superior parietal"),2), 
  p = sample(seq(0,.5,.001), 8),
  AgeG = c(rep("Young",4), rep("Old",4)),
  stringsAsFactors = FALSE)
  
ggseg(data=someData, colour="white", mapping=aes(fill=p)) +
  facet_wrap(~AgeG, ncol=1) +
  theme(legend.position = "bottom")


## ----duplicate-----------------------------------------------------------
newAtlas = list(Young = someData %>% filter(AgeG %in% "Young"),
                Old = someData %>% filter(AgeG %in% "Old")) %>% 
  lapply(function(x) x %>% full_join(dkt) %>% mutate(AgeG = unique(x$AgeG))) %>% 
  bind_rows()
newAtlas %>% head(10)

ggseg(atlas=newAtlas, colour="white", mapping=aes(fill=p)) +
  facet_wrap(~AgeG, ncol=1) +
  theme(legend.position = "bottom")

## ------------------------------------------------------------------------
vignette("externalData")

## ----datasupp4-----------------------------------------------------------
ggseg(atlas=newAtlas, colour="white", mapping=aes(fill=p)) +
  facet_wrap(~AgeG, ncol=1) +
  theme_dark() +
  theme(legend.position = "bottom",
        axis.text = element_blank(),
        axis.title = element_blank()
        ) +
  scale_fill_continuous(na.value="transparent")


## ----datasupp5-----------------------------------------------------------
ggseg(atlas=newAtlas, colour="white", mapping=aes(fill=p)) +
  facet_wrap(~AgeG, ncol=1) +
  theme_dark() +
  theme(legend.position = "bottom",
        axis.text = element_blank(),
        axis.title = element_blank()
        ) +
  scale_fill_gradient2(high="goldenrod",low="firebrick",na.value="transparent")


## ----atlases-------------------------------------------------------------
ggseg(atlas="aseg", mapping=aes(fill=area))

